@@ -42,6 +42,10 @@ targetLangs = []
 
 sourceDir = ''
 
+# Configurações
+
+configs = {}
+
 # Preservação da sintaxe Markdown DocFX
 
 mdRegex = re.compile(r'''(\]\(.+?\)[\W ]?)|          # referência de imagem ou link
@@ -219,6 +223,7 @@ def root():
     global sourceLang
     global targetLangs
     global sourceDir
+    global configs
     init()
     try:
         with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'r') as file:
@@ -243,12 +248,15 @@ def root():
 @root.command()
 @click.option('-k', '--api-key', type=str)
 @click.option('-s', '--source', type=str)
-@click.option('-t', '--target', type=list)
-def config():
+@click.option('-t', '--target', type=str)
+def config(api_key, source, target):
     """Show and set configuration"""
-    click.echo(api_key)
-    click.echo(source)
-    click.echo(target)
+    if (api_key + source + target).strip() == '':
+        print(' Source language:\t' + configs['SOURCE'])
+        print(' Target languages:\t' + configs['TARGET'])
+        print(' Yandex API key:\t' + configs['TRANSLATOR_KEY'])
+        exit()
+    re.purge
     exit()
 
 @root.command()
